<?php
// Piwik API Wrapper
// Written for the Ubuland project by David Futcher (bobbo) <bobbocanfly@gmail.com>
// and Greg Auger <gregory.auger@googlemail.com>

require_once("db.class.php");

class piwik_wrapper
{
    public $db = null;

    public function __construct()
    {
        $this->db = new db();
    }
    
    //Runs a Piwik API function (specified in $args)
    public function run_api_function($args) // $args is a array of items for the url
    {
		require("settings.php");

		$base_url = $setting_piwik_url."?module=API";
		
		$request_params = "&token_auth=".$setting_piwik_token_auth."&format=PHP";
		
		foreach ($args as $key => $value)
		{
				$request_params .= '&'.$key.'='.$value;
		}
	
		$result = file_get_contents($base_url.$request_params);

		$result = unserialize($result);

		return $result;
    }
    
    //Checks to see whether a site exists within Piwik or not
    public function site_exists($username)
    {
		if ($this->get_id_from_user($username) == 'false')
			return 'false';
		else
			return 'true';
    }
    
    //Returns a users site id
    public function get_id_from_user($username)
    {
    	// connects to piwik database (piwik_site table)
    	require("settings.php");
    	
		$this->db->setHostname($setting_piwik_db_hostname);
		$this->db->setUsername($setting_piwik_db_username);
		$this->db->setPassword($setting_piwik_db_passwd);
		$this->db->connect();

		$username = $this->db->clean($username);

		$query = "SELECT * FROM `".$setting_piwik_db_databse."`.`".$setting_piwik_db_prefix."_site` WHERE `name` = '".$username."'";

		$result = $this->db->query($query);

		if (mysql_num_rows($result) >= 1)
			while($row = mysql_fetch_array($result)) 
				return $row['idsite'];
		else
			return 'false';
    }

    //Creates a Piwik user and site
    public function create_site($username)
    {
    	if ($this->site_exists($username) == 'true')
    	{
    		return 'false';
    	}
    	else
    	{
		    $site_url = "http://".$username.".ubuland.org";

		    $addsite_args = array(
		        "method" => "SitesManager.addSite",
		        "siteName" => $username,
		        "urls" => $site_url
		    );
		    
		    // returns piwik id of new site
		    return $this->run_api_function($addsite_args);
        }
    }
    
    //Returns the Javascript results tracking code for a users site
    public function get_tracking_code($username)
    {
        $getcode_args = array(
            "method" => "SitesManager.getJavascriptTag",
            "idSite" => $this->get_id_from_user($username)
        );
      
        $result = $this->run_api_function($getcode_args);
      
        $result = trim($result);

        return $result;
    }
    
    //Returns the amount of visits in the latest $days days
    public function get_latest_visit_counts($username, $days)
    {
	    // array of values accepted by piwik api
	    $period = array(
		    "1" => "day", 
		    "7" => "week",
		    "30" => "month"
	    );    
    
        if (!(array_key_exists($days, $period)))
        {
            $arg_period = $days."days";
        }
        else
        {
            $arg_period = $period[$days];
        }
        
        $getcode_args = array(
            "method" => "VisitsSummary.getVisits",
            "idSite" => $this->get_id_from_user($username),
            "period" => $arg_period,
            "date" => "today" 
        );        
        
        return $this->run_api_function($getcode_args);
    }
    
    //
    public function get_top_countries($username, $days)
    {
	    // array of values accepted by piwik api
	    $period = array(
		    "1" => "day", 
		    "7" => "week",
		    "30" => "month"
	    );    
    
        if (!(array_key_exists($days, $period)))
        {
            $arg_period = $days."days";
        }
        else
        {
            $arg_period = $period[$days];
        }
        
        $getcode_args = array(
            "method" => "UserCountry.getCountry",
            "idSite" => $this->get_id_from_user($username),
            "period" => $arg_period,
            "date" => "today" 
        );        
        
        return $this->run_api_function($getcode_args);
    }
}

?>