<?php

// Ubuland Statistics Class (called from UCP for a Statistics Sidebar)
// Lots of inspiration from phpSysInfo

class stats
{
         public $results = array();

         // run getStats() automatically when class is created
         function __construct() {
             $this->get_stats();
         }


         // Return array of stats, this is the function to run from UCP
         function get_stats()
         {
             $this->get_vhost_name();
             $this->get_ip_address();
             $this->get_php_version();
             $this->get_kernel_version();
             $this->get_uptime();
             $this->get_load_avg();
         }
         

         // Write stat into $results
         function write_stat($statName, $stat)
         {
             $this->results[$statName] = $stat;
         }

         // Get server hostname from Apache
         function get_vhost_name()
         {
             if (!($result = getenv('SERVER_NAME'))) {
                 $result = 'Unavailable';
             } 

             $this->write_stat('hostname', $result);
         }

         // NEEDS IN PLACE TESTING ON PRODUCTION ENVIRONMENT
         function get_ip_address()
         {
             if (!($result = getenv('SERVER_ADDR'))) {
                 $result = gethostbyname($this->results['hostname']);
             }

             $this->write_stat('ip_addr', $result);
         }

         function get_php_version()
         {
             if (!($result = phpversion())) {
                 $result = "Unavailable";
             }
             else
             {
                 //Strip distributor stuff (*-ubuntu1 etc) from the end of PHP version
                 $parts = explode("-", $result);
                 $result = $parts[0];
             }

             $this->write_stat('php_version', $result);
         }

         function get_kernel_version() 
         {
             if (file_exists("/proc/version"))
             {
                 $file = fopen("/proc/version", 'r');
                 $result = fgets($file);
                 fclose($file);

                 $parts = explode(" ", $result);
                 $result = $parts[2];
             }
             else //Can this even happen?
             {
                 $result = "Unavailable";
             } 

             $this->write_stat('kernel', $result);
         }

         function get_uptime()
         {
             $file = fopen("/proc/uptime", 'r');

             if(!($sec = fgets($file))) 
             {
                 $result = "Unavailable";
             }
             else
             {
                 $sec = explode(" ", $sec);
                 $sec = $sec[0];

                 //Convert seconds to d:h:m - Thanks to Jon Haworth <jon@laughing-buddha.net>
                 $hms = "";

                 $hours = intval(intval($sec) / 3600); 
                 $days = intval(intval($hours) / 24);

                 $day_hours = intval($days * 24);
                 $hours = intval($hours - $day_hours);
                 
                 $hms .= $days." days ";

                 $hms .= ($padHours) 
                 ? str_pad($hours, 2, "0", STR_PAD_LEFT). ' hours '
                 : $hours. ' hours ';
     
                 $minutes = intval(($sec / 60) % 60); 
                 $hms .= str_pad($minutes, 2, "0", STR_PAD_LEFT). ' minutes';

                 $result = $hms;
             }
     
           $this->write_stat('uptime', $result);

         }

         /** 
         * Get server load averages
         */
         function get_load_avg()
         {
             $file = fopen("/proc/loadavg", 'r');

             if(!($result = fgets($file))) 
             {
                 $result = "Unavailable";
             }
             else
             {
                 fclose($file);     
                 $result_str = array();

                 $result = explode(" ", $result);
                 for ($i=0; $i<3; $i++)
                 {
                     $result_str .= $result[$i].' ';
                 }

                 $result = $result_str;
             }                    

             $this->write_stat('load_avg', $result);
         }

         /**
         * @todo Get username function
         * @todo Get bandwidth used function
         * @todo Get account disk usage function        
         */ 

}

?>
